@@ -95,23 +95,23 @@ def read(type, settings):
 def __read_csv(settings: dict):
     df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], parse_dates=[i for i in range(len(pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"]).columns))])
     df = normalize_columns(df)
-    df.to_parquet(settings["parquet"])
+    #df.to_parquet(settings["parquet"])
     return df
 
 def __read_excel(settings: dict):
-    df = pd.read_excel(settings["path"], parse_dates=[i for i in range(len(pd.read_excel(settings["path"])))])
+    df = pd.read_excel(settings["path"], parse_dates=[i for i in range(len(pd.read_excel(settings["path"]).columns))])
     df = normalize_columns(df)
-    df.to_parquet(settings["parquet"])
+    #df.to_parquet(settings["parquet"])
     return df
 
 def __read_gsheet(settings: dict):
     df = read_gsheet(settings["url"])
     df = normalize_columns(df)
-    df.to_parquet(settings["parquet"])
+    #df.to_parquet(settings["parquet"])
     return df
 
 def __read_hubspot(settings: dict):
     df = read_hubspot_contacts(settings["fields"]["token"])
     df = normalize_columns(df)
-    df.to_parquet(settings["parquet"])
+    #df.to_parquet(settings["parquet"])
     return df
\ No newline at end of file
